@@ -4,13 +4,14 @@
 
 __author__ = """The pyfar developers"""
 __email__ = ''
-__version__ = '0.5.2'
+__version__ = '0.6.4'
 
 
 from .classes.audio import Signal, TimeData, FrequencyData
 from .classes.audio import (add, subtract, multiply, divide, power,
                             matrix_multiplication)
 from .classes.coordinates import Coordinates
+from .classes.coordinates import (deg2rad, rad2deg)
 from .classes.orientations import Orientations
 from .classes.filter import FilterFIR, FilterIIR, FilterSOS
 
@@ -19,6 +20,7 @@ from . import samplings
 from . import io
 from . import dsp
 from . import signals
+from . import utils
 
 
 __all__ = [
@@ -32,6 +34,8 @@ __all__ = [
     'power',
     'matrix_multiplication',
     'Coordinates',
+    'deg2rad',
+    'rad2deg',
     'Orientations',
     'FilterFIR',
     'FilterIIR',
@@ -40,4 +44,5 @@ __all__ = [
     'samplings',
     'io',
     'dsp',
-    'signals']
+    'signals',
+    'utils']
