@@ -2,10 +2,12 @@ from . import audio
 from . import coordinates
 from . import orientations
 from . import filter
+from . import warnings
 
 __all__ = [
     'audio',
     'coordinates',
     'orientations',
-    'filter'
+    'filter',
+    'warnings'
 ]
