@@ -3,6 +3,7 @@ import numpy as np
 from scipy import signal as sgn
 import pyfar
 from pyfar.dsp import fft
+from pyfar.classes.warnings import PyfarDeprecationWarning
 import warnings
 
 
@@ -428,7 +429,7 @@ def time_window(signal, interval, window='hann', shape='symmetric',
         >>> for shape in ['symmetric', 'symmetric_zero', 'left', 'right']:
         >>>     signal_windowed = pf.dsp.time_window(
         ...         signal, interval=[25,45], shape=shape)
-        >>>     ax = pf.plot.time(signal_windowed, label=shape)
+        >>>     ax = pf.plot.time(signal_windowed, label=shape, unit='ms')
         >>> ax.legend(loc='right')
 
     Window with fade-in and fade-out defined by four values in `interval`.
@@ -440,7 +441,7 @@ def time_window(signal, interval, window='hann', shape='symmetric',
         >>> signal = pf.Signal(np.ones(100), 44100)
         >>> signal_windowed = pf.dsp.time_window(
         ...         signal, interval=[25, 40, 60, 90], window='hann')
-        >>> pf.plot.time(signal_windowed)
+        >>> pf.plot.time(signal_windowed, unit='ms')
 
 
     """
@@ -918,9 +919,10 @@ def minimum_phase(signal, n_fft=None, truncate=True):
         >>> # create minimum phase impulse responses
         >>> h_min = pf.dsp.minimum_phase(h_linear, truncate=False)
         >>> # plot the result
+        >>> pf.plot.use()
         >>> fig, axs = plt.subplots(3, figsize=(8, 6))
-        >>> pf.plot.time(h_linear, ax=axs[0])
-        >>> pf.plot.time(h_min, ax=axs[0])
+        >>> pf.plot.time(h_linear, ax=axs[0], unit='ms')
+        >>> pf.plot.time(h_min, ax=axs[0], unit='ms')
         >>> axs[0].grid(True)
         >>> pf.plot.freq(h_linear, ax=axs[1])
         >>> pf.plot.group_delay(h_linear, ax=axs[2], unit="ms")
@@ -963,7 +965,7 @@ def minimum_phase(signal, n_fft=None, truncate=True):
     return pyfar.Signal(data, signal.sampling_rate)
 
 
-def pad_zeros(signal, pad_width, mode='after'):
+def pad_zeros(signal, pad_width, mode='end'):
     """Pad a signal with zeros in the time domain.
 
     Parameters
@@ -975,16 +977,16 @@ def pad_zeros(signal, pad_width, mode='after'):
     mode : str, optional
         The padding mode:
 
-        ``'after'``
+        ``'end'``
             Append zeros to the end of the signal
-        ``'before'``
-            Pre-pend zeros before the starting time of the signal
+        ``'beginning'``
+            Prepend zeros to the beginning of the signal
         ``'center'``
             Insert the number of zeros in the middle of the signal.
             This mode can be used to pad signals with a symmetry with respect
             to the time ``t=0``.
 
-        The default is ``'after'``.
+        The default is ``'end'``.
 
     Returns
     -------
@@ -995,18 +997,25 @@ def pad_zeros(signal, pad_width, mode='after'):
     --------
     >>> import pyfar as pf
     >>> impulse = pf.signals.impulse(512, amplitude=1)
-    >>> impulse_padded = pf.dsp.pad_zeros(impulse, 128, mode='after')
+    >>> impulse_padded = pf.dsp.pad_zeros(impulse, 128, mode='end')
 
     """
 
     if not isinstance(signal, pyfar.Signal):
         raise TypeError('Input data has to be of type: Signal.')
 
+    if mode in ['before', 'after']:
+        warnings.warn(('Mode "before" and "after" will be renamed into '
+                       '"beginning" and "end" and can no longer be used in '
+                       'Pyfar 0.8.0.'), PyfarDeprecationWarning)
+
+        mode = 'beginning' if mode == 'before' else 'end'
+
     padded_signal = signal.flatten()
 
-    if mode in ['after', 'center']:
+    if mode in ['end', 'center']:
         pad_array = ((0, 0), (0, pad_width))
-    elif mode == 'before':
+    elif mode == 'beginning':
         pad_array = ((0, 0), (pad_width, 0))
     else:
         raise ValueError("Unknown padding mode.")
@@ -1102,11 +1111,10 @@ def time_shift(
         >>> # time domain plot
         >>> pf.plot.use('light')
         >>> _, axs = plt.subplots(2, 1)
-        >>> pf.plot.time(impulse, ax=axs[0])
-        >>> pf.plot.time(shifted, ax=axs[1])
+        >>> pf.plot.time(impulse, ax=axs[0], unit='samples')
+        >>> pf.plot.time(shifted, ax=axs[1], unit='samples')
         >>> axs[0].set_title('Original signals')
         >>> axs[1].set_title('Shifted signals')
-        >>> plt.tight_layout()
 
     Perform a linear time shift instead and pad with NaNs
 
@@ -1123,11 +1131,10 @@ def time_shift(
         >>> # time domain plot
         >>> pf.plot.use('light')
         >>> _, axs = plt.subplots(2, 1)
-        >>> pf.plot.time(impulse, ax=axs[0])
-        >>> pf.plot.time(shifted, ax=axs[1])
+        >>> pf.plot.time(impulse, ax=axs[0], unit='samples')
+        >>> pf.plot.time(shifted, ax=axs[1], unit='samples')
         >>> axs[0].set_title('Original signals')
         >>> axs[1].set_title('Shifted signals')
-        >>> plt.tight_layout()
 
     """
     if mode not in ["linear", "cyclic"]:
@@ -1237,8 +1244,16 @@ def find_impulse_response_delay(impulse_response, N=1):
         # in the strict sense, instead of the appriximation implemented in
         # pyfar.
         n_samples = impulse_response.n_samples
-        ir_minphase = sgn.minimum_phase(
-            impulse_response.time[ch], n_fft=4*n_samples)
+
+        # minimum phase warns if the input signal is not symmetric, which is
+        # not critical for this application
+        with warnings.catch_warnings():
+            warnings.filterwarnings(
+                "ignore", message="h does not appear to by symmetric",
+                category=RuntimeWarning)
+            ir_minphase = sgn.minimum_phase(
+                impulse_response.time[ch], n_fft=4*n_samples)
+
         correlation = sgn.correlate(
             impulse_response.time[ch],
             np.pad(ir_minphase, (0, n_samples - (n_samples + 1)//2)),
@@ -1265,7 +1280,7 @@ def find_impulse_response_delay(impulse_response, N=1):
         # Use only real-valued roots
         if np.all(np.isreal(roots)):
             root = roots[np.abs(roots) == np.min(np.abs(roots))]
-            start_sample = lags[argmax] + root
+            start_sample = np.squeeze(lags[argmax] + root)
         else:
             start_sample = np.nan
             warnings.warn(f"Starting sample not found for channel {ch}")
@@ -1509,9 +1524,9 @@ def deconvolve(system_output, system_input, fft_length=None, freq_range=None,
     # Check if the signals have any comments,
     # if yes: concatenate the comments for the system_response
     system_response.comment = "Calculated with pyfar.dsp.deconvolve."
-    if system_output.comment != 'none':
+    if system_output.comment != '':
         system_response.comment += f" system input: {system_output.comment}."
-    if system_input.comment != 'none':
+    if system_input.comment != '':
         system_response.comment += f" system output: {system_input.comment}."
 
     # return the impulse resonse
@@ -1529,7 +1544,10 @@ def convolve(signal1, signal2, mode='full', method='overlap_add'):
     signal1 : Signal
         The first signal
     signal2 : Signal
-        The second signal
+        The second signal. The :py:mod:`cshape <pyfar._concepts.audio_classes>`
+        of this signal must be `broadcastable
+        <https://numpy.org/doc/stable/user/basics.broadcasting.html>`_ to the
+        cshape of the first signal.
     mode : string, optional
         A string indicating the size of the output:
 
@@ -1561,8 +1579,10 @@ def convolve(signal1, signal2, mode='full', method='overlap_add'):
 
     Returns
     -------
-    Signal
-        The convolution result as a Signal object.
+    signal : Signal
+        The result of the convolution. The
+        :py:mod:`cdim <pyfar._concepts.audio_classes>` matches the bigger cdim
+        of the two input signals.
 
     Notes
     -----
@@ -1586,20 +1606,25 @@ def convolve(signal1, signal2, mode='full', method='overlap_add'):
         >>> # Plot input and output
         >>> with pf.plot.context():
         >>>     fig, ax = plt.subplots(2, 1, sharex=True)
-        >>>     pf.plot.time(s1, ax=ax[0], label='Signal 1', marker='o')
-        >>>     pf.plot.time(s2, ax=ax[0], label='Signal 2', marker='o')
+        >>>     pf.plot.time(s1, ax=ax[0], label='Signal 1', marker='o',
+        ...                  unit='samples')
+        >>>     pf.plot.time(s2, ax=ax[0], label='Signal 2', marker='o',
+        ...                  unit='samples')
         >>>     ax[0].set_title('Input Signals')
         >>>     ax[0].legend()
-        >>>     pf.plot.time(full, ax=ax[1], label='full', marker='o')
-        >>>     pf.plot.time(cut, ax=ax[1], label='cut', ls='--',  marker='o')
-        >>>     pf.plot.time(cyc, ax=ax[1], label='cyclic', ls=':', marker='o')
+        >>>     pf.plot.time(full, ax=ax[1], label='full', marker='o',
+        ...                  unit='samples')
+        >>>     pf.plot.time(cut, ax=ax[1], label='cut', ls='--',  marker='o',
+        ...                  unit='samples')
+        >>>     pf.plot.time(cyc, ax=ax[1], label='cyclic', ls=':', marker='o',
+        ...                  unit='samples')
         >>>     ax[1].set_title('Convolution Result')
         >>>     ax[1].set_ylim(-1.1, 1.1)
         >>>     ax[1].legend()
-        >>>     fig.tight_layout()
 
 
     """
+    # check input
     if not signal1.sampling_rate == signal2.sampling_rate:
         raise ValueError("The sampling rates do not match")
     fft_norm = pyfar.classes.audio._match_fft_norm(
@@ -1609,6 +1634,11 @@ def convolve(signal1, signal2, mode='full', method='overlap_add'):
             f"Invalid mode {mode}, needs to be "
             "'full', 'cut' or 'cyclic'.")
 
+    # check cdims
+    if len(signal1.cshape) != len(signal2.cshape):
+        signal1, signal2 = pyfar.utils.broadcast_cdims((signal1, signal2))
+
+    # convolve
     if method == 'overlap_add':
         res = sgn.oaconvolve(signal1.time, signal2.time, mode='full', axes=-1)
     elif method == 'fft':
@@ -1617,6 +1647,7 @@ def convolve(signal1, signal2, mode='full', method='overlap_add'):
         raise ValueError(
             f"Invalid method {method}, needs to be 'overlap_add' or 'fft'.")
 
+    # make convolution truncated or cyclic
     if mode == 'cut':
         res = res[..., :np.max((signal1.n_samples, signal2.n_samples))]
     elif mode == 'cyclic':
@@ -1862,7 +1893,8 @@ def rms(signal):
     return np.sqrt(power(signal))
 
 
-def average(signal, mode='linear', caxis=None, weights=None, keepdims=False):
+def average(signal, mode='linear', caxis=None, weights=None, keepdims=False,
+            nan_policy='raise'):
     """
     Average multi-channel signals.
 
@@ -1904,6 +1936,24 @@ def average(signal, mode='linear', caxis=None, weights=None, keepdims=False):
         If this is ``True``, the axes which are reduced during the averaging
         are kept as a dimension with size one. Otherwise, singular dimensions
         will be squeezed after averaging. The default is ``False``.
+    nan_policy: string, optional
+        Define how to handle NaNs in input signal.
+
+        ``'propagate'``
+           If the input signal includes NaNs, the corresponding averaged output
+           signal value will be NaN.
+        ``'omit'``
+           NaNs will be omitted while averaging. For each NaN value, the number
+           of values used for the average operation is also reduced by one. If
+           a signal contains only NaN values in a specific dimensions, the
+           output will be zero. For example if the second sample of a multi
+           channel signal is always NaN, the average will be zero at the
+           second sample.
+        ``'raise'``
+            A ``'ValueError'`` will be raised, if the input signal includes
+            NaNs.
+
+        The default is ``'raise'``.
 
     Returns
     --------
@@ -1923,14 +1973,15 @@ def average(signal, mode='linear', caxis=None, weights=None, keepdims=False):
                                pyfar.TimeData)):
         raise TypeError(("Input data has to be of type 'Signal', 'TimeData' "
                          "or 'FrequencyData'."))
-    if type(signal) == pyfar.TimeData and mode in ('log_magnitude_zerophase',
-                                                   'magnitude_zerophase',
-                                                   'magnitude_phase',
-                                                   'power',):
+    if type(signal) is pyfar.TimeData and mode in (
+            'log_magnitude_zerophase', 'magnitude_zerophase',
+            'magnitude_phase', 'power',):
         raise ValueError((
             f"mode is '{mode}' and signal is type '{signal.__class__}'"
             " but must be of type 'Signal' or 'FrequencyData'."))
-
+    if nan_policy not in ('propagate', 'omit', 'raise'):
+        raise ValueError("nan_policy has to be 'propagate', 'omit', or"
+                         "'raise'.")
     # check for caxis
     if caxis and np.max(caxis) > len(signal.cshape):
         raise ValueError(('The maximum of caxis needs to be smaller than '
@@ -1966,7 +2017,12 @@ def average(signal, mode='linear', caxis=None, weights=None, keepdims=False):
             """mode must be 'linear', 'magnitude_zerophase', 'power',
             'magnitude_phase' or 'log_magnitude_zerophase'."""
             )
-
+    # check if data includes NaNs and raise error or create masked array
+    if nan_policy == 'raise' and np.any(np.isnan(data)):
+        raise ValueError("The signal includes NaNs. Change 'nan_policy' to "
+                         "'propagate' or 'omit'.")
+    elif nan_policy == 'omit' and np.any(np.isnan(data)):
+        data = np.ma.masked_array(data, np.isnan(data))
     # set weights default
     if weights is not None:
         weights = np.broadcast_to(np.array(weights)[..., None],
@@ -1978,7 +2034,6 @@ def average(signal, mode='linear', caxis=None, weights=None, keepdims=False):
         data = data[0] * np.exp(1j * data[1])
     else:
         data = np.average(data, axis=axis, weights=weights, keepdims=keepdims)
-
     # reconstruct frequency data
     if mode == 'power':
         data = np.sqrt(data)
@@ -1997,7 +2052,7 @@ def average(signal, mode='linear', caxis=None, weights=None, keepdims=False):
 
 def normalize(signal, reference_method='max', domain='time',
               channel_handling='individual', target=1, limits=(None, None),
-              unit=None, return_reference=False):
+              unit=None, return_reference=False, nan_policy='raise'):
     """
     Apply a normalization.
 
@@ -2018,17 +2073,6 @@ def normalize(signal, reference_method='max', domain='time',
     ----------
     signal: Signal, TimeData, FrequencyData
         Input signal.
-    domain: string
-        Determines which data is used to compute the `reference` value.
-
-        ``'time'``
-           Use the absolute of the time domain data ``np.abs(signal.time)``.
-        ``'freq'``
-          Use the magnitude spectrum `np.abs(`signal.freq)``. Note that the
-          normalized magnitude spectrum used
-          (cf.:py:mod:`FFT concepts <pyfar._concepts.fft>`).
-
-        The default is ``'time'``.
     reference_method: string, optional
         Reference method to compute the channel-wise `reference` value using
         the data according to `domain`.
@@ -2045,6 +2089,17 @@ def normalize(signal, reference_method='max', domain='time',
             Compute the RMS per channel using :py:func:`~pyfar.dsp.rms`.
 
         The default is ``'max'``.
+    domain: string
+        Determines which data is used to compute the `reference` value.
+
+        ``'time'``
+           Use the absolute of the time domain data ``np.abs(signal.time)``.
+        ``'freq'``
+          Use the magnitude spectrum `np.abs(`signal.freq)``. Note that the
+          normalized magnitude spectrum used
+          (cf.:py:mod:`FFT concepts <pyfar._concepts.fft>`).
+
+        The default is ``'time'``.
     channel_handling: string, optional
         Define how channel-wise `reference` values are handeled for multi-
         channel signals. This parameter does not affect single-channel signals.
@@ -2088,6 +2143,21 @@ def normalize(signal, reference_method='max', domain='time',
     return_reference: bool
         If ``return_reference=True``, the function also returns the `reference`
         values for the channels. The default is ``False``.
+    nan_policy: string, optional
+        Define how to handle NaNs in input signal.
+
+        ``'propagate'``
+           If the input signal includes NaNs within the time or frequency range
+           , NaN will be used as normalization reference. The resulting output
+           signal values are NaN.
+        ``'omit'``
+           NaNs will be omitted in the normalization. Cshape will still remain,
+           as the normalized signal still includes the NaNs.
+        ``'raise'``
+            A ``'ValueError'`` will be raised, if the input signal includes
+            NaNs.
+
+        The default is 'raise'.
 
     Returns
     -------
@@ -2107,8 +2177,8 @@ def normalize(signal, reference_method='max', domain='time',
         >>> signal = pf.signals.sine(1e3, 441, amplitude=2)
         >>> signal_norm = pf.dsp.normalize(signal)
         >>> # Plot input and normalized Signal
-        >>> ax = pf.plot.time(signal, label='Original Signal')
-        >>> pf.plot.time(signal_norm, label='Normalized Signal')
+        >>> ax = pf.plot.time(signal, label='Original Signal', unit='ms')
+        >>> pf.plot.time(signal_norm, label='Normalized Signal', unit='ms')
         >>> ax.legend()
 
     Frequency normalization with a restricted frequency range and targed in dB
@@ -2124,8 +2194,9 @@ def normalize(signal, reference_method='max', domain='time',
         >>> signal_norm = pf.dsp.normalize(signal, target=10**(target_dB/20),
         ...     domain="freq", limits=(400, 600), unit="Hz")
         >>> # Plot input and normalized Signal
-        >>> ax = pf.plot.time_freq(signal_norm, label='Normalized Signal')
-        >>> pf.plot.time_freq(signal, label='Original Signal')
+        >>> ax = pf.plot.time_freq(signal_norm, label='Normalized Signal',
+        ...                        unit='ms')
+        >>> pf.plot.time_freq(signal, label='Original Signal', unit='ms')
         >>> ax[1].set_ylim(-15, 15)
         >>> ax[1].legend()
     """
@@ -2137,11 +2208,11 @@ def normalize(signal, reference_method='max', domain='time',
 
     if domain not in ('time', 'freq'):
         raise ValueError("domain must be 'time' or 'freq'.")
-    if type(signal) == pyfar.FrequencyData and domain == 'time':
+    if (type(signal) is pyfar.FrequencyData) and domain == 'time':
         raise ValueError((
             f"domain is '{domain}' and signal is type '{signal.__class__}'"
             " but must be of type 'Signal' or 'TimeData'."))
-    if type(signal) == pyfar.TimeData and domain == 'freq':
+    if (type(signal) is pyfar.TimeData) and domain == 'freq':
         raise ValueError((
             f"domain is '{domain}' and signal is type '{signal.__class__}'"
             " but must be of type 'Signal' or 'FrequencyData'."))
@@ -2155,6 +2226,14 @@ def normalize(signal, reference_method='max', domain='time',
     if (domain == "time" and unit not in ("s", None)) or \
             (domain == "freq" and unit not in ("Hz", None)):
         raise ValueError(f"'{unit}' is an invalid unit for domain {domain}")
+    if nan_policy not in ('propagate', 'omit', 'raise'):
+        raise ValueError("nan_policy has to be 'propagate', 'omit', or"
+                         "'raise'.")
+    # raise error if input includes NaNs.
+    check_nans = signal.time if domain == 'time' else signal.freq
+    if nan_policy == 'raise' and True in np.isnan(check_nans):
+        raise ValueError("The signal includes NaNs. Change 'nan_policy' to "
+                         "'propagate' or 'omit'.")
 
     # get and check the limits
     if domain == 'time':
@@ -2181,7 +2260,10 @@ def normalize(signal, reference_method='max', domain='time',
             input_data = np.abs(signal.time)
         else:
             input_data = np.abs(signal.freq)
-    # get values for normalization max or mean
+        # create masked array if data includes NaNs and nan_policy is omit
+        if nan_policy == 'omit' and True in np.isnan(input_data):
+            input_data = np.ma.masked_array(input_data, np.isnan(input_data))
+        # get values for normalization max or mean
         if reference_method == 'max':
             reference = np.max(input_data[..., limits[0]:limits[1]], axis=-1)
         elif reference_method == 'mean':
