@@ -12,6 +12,7 @@ import os.path
 import pathlib
 
 import warnings
+import pyfar as pf
 import sofar as sf
 import zipfile
 import io
@@ -167,41 +168,31 @@ def convert_sofa(sofa):
             f"DataType {sofa.GLOBAL_DataType} is not supported.")
 
     # Source
-    s_values = sofa.SourcePosition
-    s_domain, s_convention, s_unit = _sofa_pos(sofa.SourcePosition_Type)
-    source_coordinates = Coordinates(
-        s_values[:, 0],
-        s_values[:, 1],
-        s_values[:, 2],
-        domain=s_domain,
-        convention=s_convention,
-        unit=s_unit)
+    source_coordinates = _sofa_pos(
+        sofa.SourcePosition_Type, sofa.SourcePosition)
+
     # Receiver
-    r_values = sofa.ReceiverPosition
-    r_domain, r_convention, r_unit = _sofa_pos(sofa.ReceiverPosition_Type)
-    receiver_coordinates = Coordinates(
-        r_values[:, 0],
-        r_values[:, 1],
-        r_values[:, 2],
-        domain=r_domain,
-        convention=r_convention,
-        unit=r_unit)
+    receiver_coordinates = _sofa_pos(
+        sofa.ReceiverPosition_Type, sofa.ReceiverPosition)
 
     return signal, source_coordinates, receiver_coordinates
 
 
-def _sofa_pos(pos_type):
+def _sofa_pos(pos_type, coordinates):
     if pos_type == 'spherical':
-        domain = 'sph'
-        convention = 'top_elev'
-        unit = 'deg'
+        return Coordinates.from_spherical_elevation(
+            coordinates[:, 0] * np.pi / 180,
+            coordinates[:, 1] * np.pi / 180,
+            coordinates[:, 2]
+        )
     elif pos_type == 'cartesian':
-        domain = 'cart'
-        convention = 'right'
-        unit = 'met'
+        return Coordinates(
+            coordinates[:, 0],
+            coordinates[:, 1],
+            coordinates[:, 2]
+        )
     else:
         raise ValueError("Position:Type {pos_type} is not supported.")
-    return domain, convention, unit
 
 
 def read(filename):
@@ -231,6 +222,7 @@ def read(filename):
     filename = pathlib.Path(filename).with_suffix('.far')
 
     collection = {}
+    pyfar_version = None
     with open(filename, 'rb') as f:
         zip_buffer = io.BytesIO()
         zip_buffer.write(f.read())
@@ -238,17 +230,48 @@ def read(filename):
             zip_paths = zip_file.namelist()
             obj_names_hints = [
                 path.split('/')[:2] for path in zip_paths if '/$' in path]
+
+            # read build in data and look for pyfar version
             for name, hint in obj_names_hints:
-                if codec._is_pyfar_type(hint[1:]):
-                    obj = codec._decode_object_json_aided(name, hint, zip_file)
-                elif hint == '$ndarray':
-                    obj = codec._decode_ndarray(f'{name}/{hint}', zip_file)
-                else:
-                    raise TypeError(
-                        '.far-file contains unknown types.'
-                        'This might occur when writing and reading files with'
-                        'different versions of Pyfar.')
-                collection[name] = obj
+                if hint[1:] != 'BuiltinsWrapper':
+                    continue
+                obj = codec._decode_object_json_aided(name, hint, zip_file)
+                if 'pyfar.__version__' in obj:
+                    pyfar_version = obj['pyfar.__version__']
+                    del obj['pyfar.__version__']
+                if obj:
+                    collection[name] = obj
+
+            # check version (writing the version was introduced in 0.5.3)
+            if pyfar_version is None:
+                pyfar_version = "<0.5.3"
+
+            # read remaining data (pyfar objects and numpy arrays)
+            for name, hint in obj_names_hints:
+                if hint[1:] == 'BuiltinsWrapper':
+                    continue
+                try:
+                    if codec._is_pyfar_type(hint[1:]):
+                        obj = codec._decode_object_json_aided(
+                            name, hint, zip_file)
+                    elif hint == '$ndarray':
+                        obj = codec._decode_ndarray(f'{name}/{hint}', zip_file)
+                    else:
+                        raise TypeError((
+                            '.far-file contains unknown types. This might '
+                            'occur when writing and reading files with '
+                            'different versions of Pyfar.'))
+                    collection[name] = obj
+                except Exception as e:  # noqa
+                    # check for more specific pyfar errors that could be raised
+                    if "You must implement" in str(e) and \
+                            ("encode" in str(e) or "decode" in str(e)):
+                        raise e
+                    # raise general error with version hint
+                    raise TypeError((
+                        f"'{name}' object in {filename} was written with "
+                        f"pyfar {pyfar_version} and could not be read with "
+                        f"pyfar {pf.__version__}."))
 
         if 'builtin_wrapper' in collection:
             for key, value in collection['builtin_wrapper'].items():
@@ -297,6 +320,9 @@ def write(filename, compress=False, **objs):
     zip_buffer = io.BytesIO()
     builtin_wrapper = codec.BuiltinsWrapper()
     with zipfile.ZipFile(zip_buffer, "a", compression) as zip_file:
+        # write pyfar version
+        builtin_wrapper["pyfar.__version__"] = pf.__version__
+        # write requested data
         for name, obj in objs.items():
             if codec._is_pyfar_type(obj):
                 codec._encode_object_json_aided(obj, name, zip_file)
@@ -398,6 +424,7 @@ def write_audio(signal, filename, subtype=None, overwrite=True, **kwargs):
     * This function is based on :py:func:`soundfile.write`.
     * Except for the subtypes ``'FLOAT'``, ``'DOUBLE'`` and ``'VORBIS'`` ´
       amplitudes larger than +/- 1 are clipped.
+    * Only integer values are allowed for ``signal.sampling_rate``.
 
     """
     if not soundfile_imported:
@@ -407,6 +434,16 @@ def write_audio(signal, filename, subtype=None, overwrite=True, **kwargs):
     sampling_rate = signal.sampling_rate
     data = signal.time
 
+    # check sampling rate (libsoundfile only support ints)
+    if not isinstance(sampling_rate, int):
+        if sampling_rate % 1:
+            raise ValueError((
+                f"The sampling rate is {sampling_rate} but must have an "
+                f"integer value, e.g., {int(sampling_rate)} or "
+                f"{int(sampling_rate + 1)} (See pyfar.dsp.resample for help)"))
+        else:
+            sampling_rate = int(sampling_rate)
+
     # Reshape to 2D
     data = data.reshape(-1, data.shape[-1])
     if len(signal.cshape) != 1:
@@ -649,7 +686,7 @@ def read_comsol(filename, expressions=None, parameters=None):
     raw_data = np.reshape(raw_data, (n_nodes, n_entries+n_dimension))
 
     # Define pattern for regular expressions, see test files for examples
-    exp_pattern = r'([\w\/\^\*\(\)_.]+) \('
+    exp_pattern = r'([\w\/\^\*\(\)\[\]\-_.]+) \('
     domain_pattern = domain_str + r'=([0-9.]+)'
     value_pattern = r'=([0-9.]+)'
 
@@ -801,13 +838,24 @@ def read_comsol_header(filename):
     # read header
     header, _, _ = _read_comsol_get_headerline(filename)
 
-    # Define pattern for regular expressions, see test files for examples
-    exp_unit_pattern = r'([\w\(\)\/\^\*. ]+) @'
-    exp_pattern = r'([\w\/\^\*\(\)_.]+) \('
+    # Define pattern for regular expressions
+    # the general structure is of the headers is a repetition of
+    # expression (unit) @ domain=value, parameter_name=parameter_value,...,
+    # see test files for examples
+
+    # expression (unit) is the first term before @, contains arbitrary
+    # characters
+    exp_unit_pattern = r'([\w\(\)\/\^\*\[\]\-. ]+) @'
+    # separate expression and unit at whitespace and (
+    exp_pattern = r'([\w\/\^\*\(\)\[\]\-_.]+) \('
     unit_pattern = r'\(([\w\/\^\* .]+)\) @'
+    # domain (e.g., time or freq) is the first term after @
     domain_pattern = r'@ ([a-zA-Z]+)='
+    # values are numeric characters, after =
     value_pattern = r'=([0-9.]+)'
+    # parameters contain arbitrary characters, before =
     param_pattern = r'([\w\/\^_.]+)='
+    # parameter values are numeric, sometimes given with their units
     param_unit_pattern = r'=[0-9.]+([a-zA-Z]+)'
 
     # read expressions
