@@ -8,6 +8,7 @@ from .ticker import (
     LogLocatorITAToolbox,
     MultipleFractionLocator,
     MultipleFractionFormatter)
+from matplotlib.ticker import NullFormatter
 
 
 def _time_2d(signal, dB, log_prefix, log_reference, unit, indices,
@@ -101,6 +102,7 @@ def _freq_2d(signal, dB, log_prefix, log_reference, freq_scale, indices,
     ax_scale[0](freq_scale)
     if freq_scale == "log":
         axis[0].set_major_locator(LogLocatorITAToolbox())
+        axis[0].set_minor_formatter(NullFormatter())
     axis[0].set_major_formatter(LogFormatterITAToolbox())
 
     # color limits
@@ -162,6 +164,7 @@ def _phase_2d(signal, deg, unwrap, freq_scale, indices, orientation, method,
     ax_scale[0](freq_scale)
     if freq_scale == "log":
         axis[0].set_major_locator(LogLocatorITAToolbox())
+        axis[0].set_minor_formatter(NullFormatter())
     axis[0].set_major_formatter(LogFormatterITAToolbox())
 
     # colorbar
@@ -217,6 +220,7 @@ def _group_delay_2d(signal, unit, freq_scale, indices, orientation, method,
     ax_scale[0](freq_scale)
     if freq_scale == "log":
         axis[0].set_major_locator(LogLocatorITAToolbox())
+        axis[0].set_minor_formatter(NullFormatter())
     axis[0].set_major_formatter(LogFormatterITAToolbox())
 
     # color limits
@@ -351,6 +355,7 @@ def _spectrogram(signal, dB=True, log_prefix=None, log_reference=1,
         times = times * factor
 
     # plot the data
+    ax[0].grid(False)
     qm = ax[0].pcolormesh(times, frequencies, spectrogram, **kwargs)
 
     # Adjust axes:
@@ -370,6 +375,7 @@ def _spectrogram(signal, dB=True, log_prefix=None, log_reference=1,
     if freq_scale == 'log':
         ax[0].set_yscale('symlog')
         ax[0].yaxis.set_major_locator(LogLocatorITAToolbox())
+        ax[0].yaxis.set_minor_formatter(NullFormatter())
     ax[0].yaxis.set_major_formatter(LogFormatterITAToolbox())
     ax[0].grid(ls='dotted', color='white')
 
@@ -394,5 +400,6 @@ def _plot_2d(x, y, data, method, ax, **kwargs):
                     kwargs["vmin"], kwargs["vmax"], kwargs["levels"])
         qm = ax.contourf(x, y, data, **kwargs)
     else:
+        ax.grid(False)
         qm = ax.pcolormesh(x, y, data, **kwargs)
     return qm
